@@ -1,4 +1,4 @@
 from .inlinebuttons import InlineButtons
 from .reply_markup import ReplyMarkup
 from .message import Msg
-from .sendOTP import Send_OTP
+# from .sendOTP import Send_OTP
